@@ -2,7 +2,7 @@
   +----------------------------------------------------------------------+
   | uopz                                                                 |
   +----------------------------------------------------------------------+
-  | Copyright (c) Joe Watkins 2016-2019                                  |
+  | Copyright (c) Joe Watkins 2016-2020                                  |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
@@ -24,8 +24,6 @@
 #include "php_ini.h"
 #include "ext/standard/info.h"
 
-#include "SAPI.h"
-
 #include "uopz.h"
 
 #include "src/util.h"
@@ -154,8 +152,6 @@ static PHP_RINIT_FUNCTION(uopz)
 
 	uopz_request_init();
 
-	uopz_handlers_update();
-
 	return SUCCESS;
 } /* }}} */
 
